==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/ronportal/kapacity/view_detail.php <==
<?php
/**
 * stanislav.elbl, 24.11.2014
 * formular pro zobrazeni detailu
 */

namespace RonPortal\Kapacity;

use Ron\Controls\ComboBox;
use Ron\MVC\Model;
use Ron\TextManager;
use RonPortal\RonPortalSettings;
use RonPortal\TypRozdeleni;

/** @var TypRozdeleni $typRozdeleni2 */
$typRozdeleni2 = Model::getInstance() ->getData('typRozdeleni2');
/** @var ComboBox $comboTypDokumentu */
$comboTypDokumentu = Model::getInstance() ->getData('typDokumentuComboBox');

?>
<div id="kapacity_detail" class="rondialog small-padding">
    <!-- data -->
    <div style="position:relative">
        <div id="planovani_detail_waitmessage" class="dialogwaitmessage"><?= TextManager::_('Probiha_nacitani') ?></div>

        <table>
            <!-- detail smeny -->
            <tbody id="planovani_detail_body_smena">
            <tr>
                <td colspan="4"><div class="form-section"><?= TextManager::_('Smena') ?></div></td>
            </tr>

            <tr>
                <td colspan="2" class="align-right"><?= TextManager::_('Smena') ?></td>
<!--                <td id='planovani_detail_popissmeny'>popis smeny ...</td>-->
<!--                <td id='planovani_detail_kodsmeny'></td>-->
                <td id='planovani_detail_popissmeny'>
                    <input name="detail_popissmeny" id="detail_popissmeny" class="planovani_detailpopis">
                </td>
                <td id='planovani_detail_kodsmeny'>
                    <input name="detail_kodsmeny" id="detail_kodsmeny" class="planovani_detailkod">
                </td>
            </tr>

            <tr>
                <td colspan="2" class="align-right"><?= TextManager::_('Od') ?></td>
                <td colspan="2">

                    <span id='variabilni_smena'>
                       <input id='planovani_detail_smena_pocatek' class="app_input inputTime" type="text" name="smena_pocatek" maxlength="5" size="5" value="" />
                       <span id='planovani_detail_smena_pocatek_text' style="display:none"></span>
                       &nbsp;&nbsp; <?= TextManager::_('Do') ?>
                         <input id='planovani_detail_smena_konec' class="app_input inputTime" type="text" name="smena_konec" maxlength="5" size="5" value="" />
                       <span id='planovani_detail_smena_konec_text' style="display:none"></span>
                       &nbsp;&nbsp; <?= TextManager::_('Delka') ?>
                         <input id='planovani_detail_smena_delka' class="app_input inputTime" type="text" name="smena_delka" maxlength="5" size="5" value="" />
                       <span id='planovani_detail_smena_delka_text' style="display:none"></span>
                    </span>

                    <span id='delena_smena'>
                       <?= TextManager::_('Preruseni_od') ?>
                       <input id='planovani_detail_smena_preruseniOd' class="app_input inputTime" type="text" name="smena_preruseniOd" maxlength="5" size="5" value="" />
                       <?= TextManager::_('do') ?>
                       <input id='planovani_detail_smena_preruseniDo' class="app_input inputTime" type="text" name="smena_preruseniDo" maxlength="5" size="5" value="" />
                    </span>

                    <span class="planovani_detail_userinfo"><?= TextManager::_('Kalendar') ?>: <span class="planovani_user" id="planovani_detail_kalendar"></span></span>
                </td>
            </tr>

            <?php if (RonPortalSettings::getIntValue(KapacitySettings::KAPACITY_TYP_ROZDELENI)) { ?>
                <tr id="planovani_detail_rozdelenirow">
                    <td colspan="2" class="align-right"><?= TextManager::_('Rozdeleni_PK') ?></td>
                    <td colspan="2">
                        <span id="planovani_detail_rozdeleni"></span>
                        <span class="planovani_detail_userinfo"><?= TextManager::_('Editoval') ?>: <span class="planovani_user" id="planovani_detail_editoval"></span></span>
                    </td>
                </tr>
            <?php } ?>


            <?php if (RonPortalSettings::getIntValue(KapacitySettings::POVOLIT_REZIM_UPRAV)) { ?>
                <tr id="planovani_detail_puvodnismenarow">
                    <td colspan="2" class="align-right"><?= TextManager::_('Puvodni_plan') ?></td>
                    <td colspan="2" id="planovani_detail_puvodnismena"></td>
                </tr>
            <?php } ?>

            <?php if (RonPortalSettings::getIntValue(KapacitySettings::KAPACITY_TYP_ROZDELENI2)) { ?>
                <tr id="planovani_detail_rozdeleni2row">
                    <td colspan="2" class="align-right"><?= $typRozdeleni2 ->popis ?></td>
                    <td id='planovani_detail_rozdeleni2'>
                        <input name="detail_popisrozdeleni2" id="detail_popisrozdeleni2" class="planovani_detailpopis">
                    </td>
                    <td id='planovani_detail_kodrozdeleni2'>
                        <input name="detail_kodrozdeleni2" id="detail_kodrozdeleni2" class="planovani_detailkod">
                    </td>
                </tr>
            <?php } ?>

            </tbody>

            <!-- poznamka k dochazce -->
            <tbody id="planovani_detail_body_poznamkadochazky">
            <tr>
                <td colspan="4"><div class="form-section"><?= TextManager::_('Poznamka_k_dochazce') ?></div></td>
            </tr>

            <tr>
                <td></td>
                <td></td>
                <td colspan="2"><textarea name="poznamkadochazky" id="planovani_detail_poznamkadochazky" class="planovani_textpoznamky form-input"></textarea></td>
            </tr>
            </tbody>

            <!-- dokumenty ke dni dochazky -->
            <tbody id="planovani_detail_body_dokumenty">
            <tr>
                <td colspan="4"><div class="form-section"><?= TextManager::_('Dokumenty') ?></div></td>
            </tr>

            <tr>
                <td><div><a id="planovani_detail_vlozit_dokument" href="#"><?= TextManager::_('Vlozit_novy_dokument') ?></a></div></td>
                <td></td>
                <td colspan="2" id="planovani_detail_seznamdokumentu">
<!--                    <div><a href="abc">Dokument 1</a></div>-->
                </td>
            </tr>
            </tbody>

            <tbody id="planovani_detail_upload" style="display: none;">
            <tr>
                <td colspan="2"></td>
                <td><?= TextManager::_('Popis') ?></td>
                <td><?= TextManager::_('Typ') ?></td>
            </tr>

            <tr>
                <td colspan="2" rowspan="2">
                    <input type="file" name="dokument" id="planovani_detail_dokument"/>
                    <div id="planovani_detail_soubory"></div>
                </td>
                <td><input type="text" class="form-input planovani_detailpopis" id="planovani_detail_popis_dokumentu" maxlength="160" size="50"/></td>
                <td><?php $comboTypDokumentu ->render(); ?></td>
            </tr>

            <tr>
                <!-- 2x td z predchoziho radku s rowspan="2" -->
                <td colspan="2">
                    <input type="button" class="submitbutton" id="planovani_detail_dokument_ok" value="<?= TextManager::_('OK') ?>">
                    <input type="button" class="button" id="planovani_detail_dokument_storno" value="<?= TextManager::_('Cancel') ?>">
                </td>
            </tr>
            </tbody>


            <!-- detail absenci -->
            <tbody id="planovani_detail_body_absence">
            <tr>
                <!-- nadpis -->
                <td colspan="4">
                    <div class="form-section"><?= TextManager::_('Absence_a_udalosti') ?></div>
                </td>
            </tr>

            <tr>
                <!-- seznam absenci v aktualnim dni -->
                <td id="planovani_detail_seznamabsenci" rowspan="6" class="planovani_detail_seznamabsenci rowOver"></td>
                <td></td>

                <!-- popis, kod -->
                <td colspan="2">
                    <span class="planovani_detail_userinfo" id="planovani_detail_schvaleni">
                        <?php if (RonPortalSettings::getIntValue(RonPortalSettings::ABSENCE_SCHVALOVANI)) { ?>
                            <?= TextManager::_('Schvalil') ?>: <span class="planovani_user" id="planovani_detail_absencischvalil"></span>
                        <?php } ?>
                    </span>

                    <div id="planovani_detail_popisabsence"></div>
                </td>
            </tr>

            <tr>
                <td class="align-right"><?= TextManager::_('Od') ?></td>
                <td colspan="2">
                    <!-- datum absence od-do, cas od-do pro kontinualni absenci -->
                    <input id='planovani_detail_absenceod' class="app_input inputDate" type="text" name="datumabsenceod" maxlength="10" size="10" value="" data-roncalendar-next="datumabsencedo" />
                    <!--suppress HtmlUnknownTarget -->
                    <i id="planovani_detail_kalendarod" class="showcalendar inline-glyph glyph-button fa glyph-calendar" data-roncalendar-inputname="datumabsenceod"></i>
                    <input id="planovani_detail_kontinualniod" class="app_input inputTime" style="display:none" type="text" name="caskontinualniod" maxlength="5" size="5" value="" />
                    &nbsp;&nbsp; <?= TextManager::_('Do') ?>
                    <input id='planovani_detail_absencedo' class="app_input inputDate" type="text" name="datumabsencedo" maxlength="10" size="10" value="" data-roncalendar-prev="datumabsenceod" />
                    <!--suppress HtmlUnknownTarget -->
                    <i id='planovani_detail_kalendardo' class="showcalendar inline-glyph glyph-button fa glyph-calendar" data-roncalendar-inputname="datumabsencedo"></i>
                    <input id="planovani_detail_kontinualnido" class="app_input inputTime" style="display:none" type="text" name="caskontinualnido" maxlength="5" size="5" value="" />
                </td>
            </tr>

            <tr>
                <!-- delka absence, cas od-do -->
                <td class="align-right"><?= TextManager::_('Delka_absence') ?></td>
                <td colspan="2">
                    <select name="detail_delkaabsence" id="detail_delkaabsence" class="app_input" >
                        <option value=""></option>
                        <option value="0"><?= TextManager::_('Absence_cela_smena') ?></option>
                        <option value="1"><?= TextManager::_('Absence_pulka_smeny1') ?></option>
                        <option value="2"><?= TextManager::_('Absence_pulka_smeny2') ?></option>
                        <option value="3"><?= TextManager::_('Absence_od_do') ?></option>
                        <option value="4"><?= TextManager::_('Absence_kontinualne') ?></option>
                    </select>
                    <div id='planovani_detail_casyabsence' style="display:inline-block">
                        <input id='planovani_detail_casabsenceod' class="app_input inputTime" type="text" name="casabsenceod" maxlength="5" size="5" value="" />
                        &nbsp;-&nbsp;
                        <input id='planovani_detail_casabsencedo' class="app_input inputTime" type="text" name="casabsencedo" maxlength="5" size="5" value="" />
                    </div>
                    <span class="planovani_detail_userinfo"><?= TextManager::_('Vlozil') ?>: <span class="planovani_user" id="planovani_detail_absencivlozil"></span></span>
                </td>
            </tr>

            <tr>
                <!-- rozdeleni -->
                <td class="align-right"><span id="planovani_typ_rozdeleni_absence"></span></td>
                <td colspan="2"><span id="planovani_rozdeleni_absence"></span></td>
            </tr>

            <tr>
                <td></td>
                <td colspan="2">
                    <?= TextManager::_('Poznamka_k_absenci') ?>
                    <span class="planovani_detail_userinfo"><?= TextManager::_('Editoval') ?>: <span class="planovani_user" id="planovani_detail_absencieditoval"></span></span>
                </td>
            </tr>

            <tr>
                <td></td>
                <td colspan="2"><textarea name="poznamkaabsence" id="planovani_detail_poznamkaabsence" class="planovani_textpoznamky form-input"></textarea></td>
            </tr>
            </tbody>

        </table>
    </div>



    <!-- tlacitka -->
    <div class="buttons">
        <button id="detail_ok" type="button" class="submitbutton"><?= TextManager::_('OK') ?></button>
        <button id="detail_storno" type="button" class="button"><?= TextManager::_('Cancel') ?></button>
    </div>
</div>

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2311_175.zip: ronportal/ronportal/kapacity/view_detail.php <==
<?php
/**
 * stanislav.elbl, 24.11.2014
 * formular pro zobrazeni detailu
 */

namespace RonPortal\Kapacity;

use Ron\Controls\ComboBox;
use Ron\MVC\Model;
use Ron\TextManager;
use RonPortal\RonPortalSettings;
use RonPortal\TypRozdeleni;

/** @var TypRozdeleni $typRozdeleni2 */
$typRozdeleni2 = Model::getInstance() ->getData('typRozdeleni2');
/** @var ComboBox $comboTypDokumentu */
$comboTypDokumentu = Model::getInstance() ->getData('typDokumentuComboBox');

?>
<div id="kapacity_detail" class="rondialog small-padding">
    <!-- data -->
    <div class="position-relative">
        <div id="planovani_detail_waitmessage" class="dialogwaitmessage"><?= TextManager::_('Probiha_nacitani') ?></div>

        <table>
            <!-- detail smeny -->
            <tbody id="planovani_detail_body_smena">
            <tr>
                <td colspan="4"><div class="form-section"><?= TextManager::_('Smena') ?></div></td>
            </tr>

            <tr>
                <td colspan="2" class="align-right"><?= TextManager::_('Smena') ?></td>
<!--                <td id='planovani_detail_popissmeny'>popis smeny ...</td>-->
<!--                <td id='planovani_detail_kodsmeny'></td>-->
                <td id='planovani_detail_popissmeny'>
                    <input name="detail_popissmeny" id="detail_popissmeny" class="planovani_detailpopis">
                </td>
                <td id='planovani_detail_kodsmeny'>
                    <input name="detail_kodsmeny" id="detail_kodsmeny" class="planovani_detailkod">
                </td>
            </tr>

            <tr>
                <td colspan="2" class="align-right"><?= TextManager::_('Od') ?></td>
                <td colspan="2">

                    <span id='variabilni_smena'>
                       <input id='planovani_detail_smena_pocatek' class="app_input inputTime" type="text" name="smena_pocatek" maxlength="5" size="5" value="" />
                       <span id='planovani_detail_smena_pocatek_text' class="d-none"></span>
                       &nbsp;&nbsp; <?= TextManager::_('Do') ?>
                         <input id='planovani_detail_smena_konec' class="app_input inputTime" type="text" name="smena_konec" maxlength="5" size="5" value="" />
                       <span id='planovani_detail_smena_konec_text' class="d-none"></span>
                       &nbsp;&nbsp; <?= TextManager::_('Delka') ?>
                         <input id='planovani_detail_smena_delka' class="app_input inputTime" type="text" name="smena_delka" maxlength="5" size="5" value="" />
                       <span id='planovani_detail_smena_delka_text' class="d-none"></span>
                    </span>

                    <span id='delena_smena'>
                       <?= TextManager::_('Preruseni_od') ?>
                       <input id='planovani_detail_smena_preruseniOd' class="app_input inputTime" type="text" name="smena_preruseniOd" maxlength="5" size="5" value="" />
                       <?= TextManager::_('do') ?>
                       <input id='planovani_detail_smena_preruseniDo' class="app_input inputTime" type="text" name="smena_preruseniDo" maxlength="5" size="5" value="" />
                    </span>

                    <span class="planovani_detail_userinfo"><?= TextManager::_('Kalendar') ?>: <span class="planovani_user" id="planovani_detail_kalendar"></span></span>
                </td>
            </tr>

            <?php if (RonPortalSettings::getIntValue(KapacitySettings::KAPACITY_TYP_ROZDELENI)) { ?>
                <tr id="planovani_detail_rozdelenirow">
                    <td colspan="2" class="align-right"><?= TextManager::_('Rozdeleni_PK') ?></td>
                    <td colspan="2">
                        <span id="planovani_detail_rozdeleni"></span>
                        <span class="planovani_detail_userinfo"><?= TextManager::_('Editoval') ?>: <span class="planovani_user" id="planovani_detail_editoval"></span></span>
                    </td>
                </tr>
            <?php } ?>


            <?php if (RonPortalSettings::getIntValue(KapacitySettings::POVOLIT_REZIM_UPRAV)) { ?>
                <tr id="planovani_detail_puvodnismenarow">
                    <td colspan="2" class="align-right"><?= TextManager::_('Puvodni_plan') ?></td>
                    <td colspan="2" id="planovani_detail_puvodnismena"></td>
                </tr>
            <?php } ?>

            <?php if (RonPortalSettings::getIntValue(KapacitySettings::KAPACITY_TYP_ROZDELENI2)) { ?>
                <tr id="planovani_detail_rozdeleni2row">
                    <td colspan="2" class="align-right"><?= $typRozdeleni2 ->popis ?></td>
                    <td id='planovani_detail_rozdeleni2'>
                        <input name="detail_popisrozdeleni2" id="detail_popisrozdeleni2" class="planovani_detailpopis">
                    </td>
                    <td id='planovani_detail_kodrozdeleni2'>
                        <input name="detail_kodrozdeleni2" id="detail_kodrozdeleni2" class="planovani_detailkod">
                    </td>
                </tr>
            <?php } ?>

            </tbody>

            <!-- poznamka k dochazce -->
            <tbody id="planovani_detail_body_poznamkadochazky">
            <tr>
                <td colspan="4"><div class="form-section"><?= TextManager::_('Poznamka_k_dochazce') ?></div></td>
            </tr>

            <tr>
                <td></td>
                <td></td>
                <td colspan="2"><textarea name="poznamkadochazky" id="planovani_detail_poznamkadochazky" class="planovani_textpoznamky form-input"></textarea></td>
            </tr>
            </tbody>

            <!-- dokumenty ke dni dochazky -->
            <tbody id="planovani_detail_body_dokumenty">
            <tr>
                <td colspan="4"><div class="form-section"><?= TextManager::_('Dokumenty') ?></div></td>
            </tr>

            <tr>
                <td><div><a id="planovani_detail_vlozit_dokument" href="#"><?= TextManager::_('Vlozit_novy_dokument') ?></a></div></td>
                <td></td>
                <td colspan="2" id="planovani_detail_seznamdokumentu">
<!--                    <div><a href="abc">Dokument 1</a></div>-->
                </td>
            </tr>
            </tbody>

            <tbody id="planovani_detail_upload" class="d-none">
            <tr>
                <td colspan="2"></td>
                <td><?= TextManager::_('Popis') ?></td>
                <td><?= TextManager::_('Typ') ?></td>
            </tr>

            <tr>
                <td colspan="2" rowspan="2">
                    <input type="file" name="dokument" id="planovani_detail_dokument"/>
                    <div id="planovani_detail_soubory"></div>
                </td>
                <td><input type="text" class="form-input planovani_detailpopis" id="planovani_detail_popis_dokumentu" maxlength="160" size="50"/></td>
                <td><?php $comboTypDokumentu ->render(); ?></td>
            </tr>

            <tr>
                <!-- 2x td z predchoziho radku s rowspan="2" -->
                <td colspan="2">
                    <input type="button" class="submitbutton" id="planovani_detail_dokument_ok" value="<?= TextManager::_('OK') ?>">
                    <input type="button" class="button" id="planovani_detail_dokument_storno" value="<?= TextManager::_('Cancel') ?>">
                </td>
            </tr>
            </tbody>


            <!-- detail absenci -->
            <tbody id="planovani_detail_body_absence">
            <tr>
                <!-- nadpis -->
                <td colspan="4">
                    <div class="form-section"><?= TextManager::_('Absence_a_udalosti') ?></div>
                </td>
            </tr>

            <tr>
                <!-- seznam absenci v aktualnim dni -->
                <td id="planovani_detail_seznamabsenci" rowspan="6" class="planovani_detail_seznamabsenci rowOver"></td>
                <td></td>

                <!-- popis, kod -->
                <td colspan="2">
                    <span class="planovani_detail_userinfo" id="planovani_detail_schvaleni">
                        <?php if (RonPortalSettings::getIntValue(RonPortalSettings::ABSENCE_SCHVALOVANI)) { ?>
                            <?= TextManager::_('Schvalil') ?>: <span class="planovani_user" id="planovani_detail_absencischvalil"></span>
                        <?php } ?>
                    </span>

                    <div id="planovani_detail_popisabsence"></div>
                </td>
            </tr>

            <tr>
                <td class="align-right"><?= TextManager::_('Od') ?></td>
                <td colspan="2">
                    <!-- datum absence od-do, cas od-do pro kontinualni absenci -->
                    <input id='planovani_detail_absenceod' class="app_input inputDate" type="text" name="datumabsenceod" maxlength="10" size="10" value="" data-roncalendar-next="datumabsencedo" />
                    <!--suppress HtmlUnknownTarget -->
                    <i id="planovani_detail_kalendarod" class="showcalendar inline-glyph glyph-button fa glyph-calendar" data-roncalendar-inputname="datumabsenceod"></i>
                    <input id="planovani_detail_kontinualniod" class="app_input inputTime d-none" type="text" name="caskontinualniod" maxlength="5" size="5" value="" />
                    &nbsp;&nbsp; <?= TextManager::_('Do') ?>
                    <input id='planovani_detail_absencedo' class="app_input inputDate" type="text" name="datumabsencedo" maxlength="10" size="10" value="" data-roncalendar-prev="datumabsenceod" />
                    <!--suppress HtmlUnknownTarget -->
                    <i id='planovani_detail_kalendardo' class="showcalendar inline-glyph glyph-button fa glyph-calendar" data-roncalendar-inputname="datumabsencedo"></i>
                    <input id="planovani_detail_kontinualnido" class="app_input inputTime d-none" type="text" name="caskontinualnido" maxlength="5" size="5" value="" />
                </td>
            </tr>

            <tr>
                <!-- delka absence, cas od-do -->
                <td class="align-right"><?= TextManager::_('Delka_absence') ?></td>
                <td colspan="2">
                    <select name="detail_delkaabsence" id="detail_delkaabsence" class="app_input" >
                        <option value=""></option>
                        <option value="0"><?= TextManager::_('Absence_cela_smena') ?></option>
                        <option value="1"><?= TextManager::_('Absence_pulka_smeny1') ?></option>
                        <option value="2"><?= TextManager::_('Absence_pulka_smeny2') ?></option>
                        <option value="3"><?= TextManager::_('Absence_od_do') ?></option>
                        <option value="4"><?= TextManager::_('Absence_kontinualne') ?></option>
                    </select>
                    <div id='planovani_detail_casyabsence' class="d-inline-block">
                        <input id='planovani_detail_casabsenceod' class="app_input inputTime" type="text" name="casabsenceod" maxlength="5" size="5" value="" />
                        &nbsp;-&nbsp;
                        <input id='planovani_detail_casabsencedo' class="app_input inputTime" type="text" name="casabsencedo" maxlength="5" size="5" value="" />
                    </div>
                    <span class="planovani_detail_userinfo"><?= TextManager::_('Vlozil') ?>: <span class="planovani_user" id="planovani_detail_absencivlozil"></span></span>
                </td>
            </tr>

            <tr>
                <!-- rozdeleni -->
                <td class="align-right"><span id="planovani_typ_rozdeleni_absence"></span></td>
                <td colspan="2"><span id="planovani_rozdeleni_absence"></span></td>
            </tr>

            <tr>
                <td></td>
                <td colspan="2">
                    <?= TextManager::_('Poznamka_k_absenci') ?>
                    <span class="planovani_detail_userinfo"><?= TextManager::_('Editoval') ?>: <span class="planovani_user" id="planovani_detail_absencieditoval"></span></span>
                </td>
            </tr>

            <tr>
                <td></td>
                <td colspan="2"><textarea name="poznamkaabsence" id="planovani_detail_poznamkaabsence" class="planovani_textpoznamky form-input"></textarea></td>
            </tr>
            </tbody>

        </table>
    </div>



    <!-- tlacitka -->
    <div class="buttons">
        <button id="detail_ok" type="button" class="submitbutton"><?= TextManager::_('OK') ?></button>
        <button id="detail_storno" type="button" class="button"><?= TextManager::_('Cancel') ?></button>
    </div>
</div>
